
:autogenerated:

..
    This file is autogenerated by `sphinx-api`.

############################
Sample usage for concordance
############################

.. include:: ../../nltk/test/concordance.doctest